# GIF2TTY: Play GIF on TTY

You can use this package to play gif file on tty device in grayscale or 8bit color mode

## Installation

```bash
$ pip install gif2tty
```

## Help
See more generation/display options:

```bash
$ gif2tty --help
```